##########################################################################################################################################
### Identification of potential biomarkers for anti-PD-1 therapy in melanoma by weighted correlation network analysis, Mar 25th, 2020.
### Author: Xuanyi Wang, Zixuan Chai 1, Yinghong Li, Fei Long, Youjin Hao, Guizhi Pan, Mingwei Liu, and Bo Li.
##########################################################################################################################################

### **************************************************************************
### A random forest model for predicting the response to anti PD-1 therapy
### **************************************************************************

### ----------------------1.1 Setting the work dir.------------------------- ### 

rm(list = ls())
options(stringsAsFactors = F)
setwd(':/')

### --------------------------1.2 load packages.---------------------------- ### 

library(randomForest)
library(ROCR)
library(genefilter)
library(Hmisc)
library(caret)
library(ROCR)

### ----1.3 load the random forest model for predicting the response to anti PD-1 therapy.---- ### 

load("rf_output.Rdata")

### -------------------1.4 Reading gene expression data.-------------------- ### 

exprSet <- read.table("input_FPKM.txt", sep='\t', row.names=1, header=T, 
                          quote="", comment="", check.names=F)

### -----------------------1.5 Building input matrix.----------------------- ### 

exprSet_6genes_choose=(exprSet[c('CD8A','IRF1','IRF8','JAK2','SELL','STAT5B'),])
Preprocessing_input = t(log2(exprSet_6genes_choose+1))
dat_input=as.data.frame(Preprocessing_input)

### -----------------------1.6 Predicting input data.----------------------- ### 

rf.prob <- predict(rf_output, dat_input)
rf.prob=as.data.frame(rf.prob)
colnames(rf.prob)='prob'

### --------------------1.7 Exporting Prediction results-------------------- ### 

write.table(rf.prob, file="rf.prob.txt", quote=FALSE)
